@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 15.2.4 Debian package creator
-# Release 2019-02-12
+# DaVinci Resolve 15.3 Debian package creator
+# Release 2019-03-07
 # By Daniel Tufvesson
 #
 
@@ -21,14 +21,14 @@ copy_object() {
 	    ERRORS=$((ERRORS+1))
 	fi
     else
-	echo "[MISSING] $1"
+	echo "[ERROR: MISSING] $1"
 	ERRORS=$((ERRORS+1))
     fi
 }
 
 create_directory() {
     if [ -e "$1" ] ; then
-	echo "[DIRECTORY EXISTS] $1"
+	echo "[ERROR: DIRECTORY EXISTS] $1"
 	ERRORS=$((ERRORS+1))
     else
 	echo "[CREATE DIRECTORY] $1"
@@ -41,13 +41,13 @@ make_executable() {
 	echo "[MAKE EXECUTABLE] $1"
 	chmod a+x "$1"
     else
-	echo "[MISSING] $1"
+	echo "[ERROR: MISSING] $1"
 	ERRORS=$((ERRORS+1))
     fi
 }
 
 # Setup variables
-RESOLVE_VERSION=15.2.4
+RESOLVE_VERSION=15.3
 DEB_STEPPING=1
 case $1 in
     studio)
